@@ -28,4 +28,5 @@ def fetch_and_update_by_tdx():
 
 
 if __name__ == '__main__':
-    fetch_and_update_by_tdx()
\ No newline at end of file
+    # fetch_and_update_by_tdx()
+    pass
\ No newline at end of file
